Reference
=========

.. module:: diofant

Most of the things are already documented though in this document, that is
automatically generated using Diofant's docstrings.

.. tip::

    Because every feature of Diofant must have a test case, when you are not
    sure how to use something, just look into the ``tests`` subdirectories,
    find that feature and read the tests for it.

.. toctree::
   :maxdepth: 2

   core
   combinatorics/index
   ntheory
   concrete
   functions/index
   geometry/index
   integrals
   logic
   domains
   matrices/index
   polys
   printing
   interactive
   plotting
   series
   sets
   simplify/simplify
   stats
   solvers/index
   tensor/index
   utilities/index
   parsing
   calculus/index
   diffgeom
   vector/index
